@@ -24,6 +24,8 @@ for my $io (
 
     while (<I>) {
         s/\\x81-\\x9F\\xE0-\\xFC/\\x81-\\xFE/g;
+        s/\(\?:8\[1-9A-Fa-f\]\|9\[0-9A-Fa-f\]\|\[Ee\]\[0-9A-Fa-f\]\|\[Ff\]\[0-9A-Ca-c\]\)/(?:8[1-9A-Fa-f]|[9A-Ea-e][0-9A-Fa-f]|[Ff][0-9A-Ea-e])/g;
+        s/\(\?:20\[1-7\]\|2\[123\]\[0-7\]\|3\[4-6\]\[0-7\]\|37\[0-4\]\)/(?:2[0-7][1-7]|3[0-7][0-6])/g;
         s/\\x40-\\x7E\\x80-\\xFC/\\x40-\\x7E\\x80-\\xFE/g;
         s/\bEsjis\b/Ebig5plus/g;
         s/ShiftJIS/Big5Plus/g;
